@@ -1,4 +1,4 @@
-package cppAdaptive2 v3.0.0;
+package cppAdaptive2 v3.0.1;
 
 use strict;
 use warnings;
@@ -20,12 +20,12 @@ use cppAdaptive2::Inline(
 
 #include "cppAdaptive.cpp"
 
-AV* _update(char* obsVector, char* futVector, char* betaVector, int n_observed) {
+AV* _update(int threads, char* obsVector, char* futVector, char* betaVector, int n_observed) {
     string obsVector1(obsVector);
     string futVector1(futVector);
     string betaVector1(betaVector);
 
-    cppAdaptive(obsVector1, futVector1, betaVector1, n_observed);
+    cppAdaptive(threads, obsVector1, futVector1, betaVector1, n_observed);
 
     AV* av = newAV();
     sv_2mortal((SV*)av);
@@ -51,9 +51,9 @@ CPP
 );
 
 sub update {
-    my ( $obsVector, $futVector, $betaVector, $n_observed ) = @_;
+    my ( $threads, $obsVector, $futVector, $betaVector, $n_observed ) = @_;
 
-    return @{ _update( $obsVector, $futVector, $betaVector, $n_observed ) };
+    return @{ _update( $threads, $obsVector, $futVector, $betaVector, $n_observed ) };
 }
 
 1;
@@ -77,6 +77,10 @@ cppAdaptive2 - cppAdaptive2 XS
         4,
     );
 
+    my $threads = 2;
+
+    my ( $newFutVector, $newBetaVector ) = cppAdaptive2::update( $threads, $obsVector, $futVector, $betaVector, $n_observed );
+
 =head1 DESCRIPTION
 
 =head1 ATTRIBUTES
